@@ -3,4 +3,4 @@ use strict;
 use TSPostfix3;
 
 my $parser = new TSPostfix3();
-$parser->Run;
+$parser->Run(@ARGV);
