@@ -35,8 +35,7 @@ package main;
 use strict;
 
 my $calcparser = CalcActions->new();
-print "Write an expression: "; 
-my $x = <STDIN>;
+my $x = "@ARGV";
 my $e = $calcparser->Run(0, $x);
 
 unless ($calcparser->YYNberr) {
