@@ -1,9 +1,15 @@
 ########################################################################################
 #
-#    This file was generated using Parse::Eyapp version 1.182.
+#    This file was generated using Parse::Eyapp version 1.2.
+#
+# Copyright © 2006, 2007, 2008, 2009, 2010, 2011, 2012 Casiano Rodriguez-Leon.
+# Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
+#
+# Parse::Yapp is Copyright © 1998, 1999, 2000, 2001, Francois Desarmenien.
+# Parse::Yapp is Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
 #
-# (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
-# (c) Parse::Eyapp Copyright 2006-2008 Casiano Rodriguez-Leon. Universidad de La Laguna.
 #        Don't edit this file, use source file 'lib/Parse/Eyapp/Parse.yp' instead.
 #
 #             ANY CHANGE MADE HERE WILL BE LOST !
@@ -28,10 +34,16 @@ BEGIN {
 
 sub unexpendedInput { defined($_) ? substr($_, (defined(pos $_) ? pos $_ : 0)) : '' }
 
-# (c) Copyright Casiano Rodriguez-Leon 
-# Based on the original yapp by Francois Desarmenien 1998-2001
-# (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien, all rights reserved.
-# (c) Parse::Eyapp Copyright 2006-2008 Casiano Rodriguez Leon, all rights reserved.
+
+# Copyright © 2006, 2007, 2008, 2009, 2010, 2011, 2012 Casiano Rodriguez-Leon.
+# Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
+#
+# Based on Parse::Yapp.
+#
+# Parse::Yapp is Copyright © 1998, 1999, 2000, 2001, Francois Desarmenien.
+# Parse::Yapp is Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
 
 require 5.004;
 
@@ -346,6 +358,61 @@ CONFLICT_EXPLORER
 
 
 
+# Default lexical analyzer
+our $LEX = sub {
+    my $self = shift;
+    my $pos;
+
+    for (${$self->input}) {
+      
+
+      m{\G(\s+)}gc and $self->tokenline($1 =~ tr{\n}{});
+
+      m{\G(INCREMENTAL|VIEWPOINT|EXPLORER|EXPECTRR|REGEXP|WHITES|DUMMY|DPREC|LEXER|\n|\:\:|\%\%|\(|\?|\||\=|\<|\%|\!|\>|\:|\)|\$|\;|\.)}gc and return ($1, $1);
+
+      /\G(ASSOC)/gc and return ($1, $1);
+      /\G(BEGINCODE)/gc and return ($1, $1);
+      /\G(CODE)/gc and return ($1, $1);
+      /\G(CONFLICT)/gc and return ($1, $1);
+      /\G(DEFAULTACTION)/gc and return ($1, $1);
+      /\G(EXPECT)/gc and return ($1, $1);
+      /\G(HEADCODE)/gc and return ($1, $1);
+      /\G(IDENT)/gc and return ($1, $1);
+      /\G(LABEL)/gc and return ($1, $1);
+      /\G(LITERAL)/gc and return ($1, $1);
+      /\G(METATREE)/gc and return ($1, $1);
+      /\G(NAME)/gc and return ($1, $1);
+      /\G(NAMINGSCHEME)/gc and return ($1, $1);
+      /\G(NOCOMPACT)/gc and return ($1, $1);
+      /\G(NUMBER)/gc and return ($1, $1);
+      /\G(OPTION)/gc and return ($1, $1);
+      /\G(PLUS)/gc and return ($1, $1);
+      /\G(PREC)/gc and return ($1, $1);
+      /\G(PREFIX)/gc and return ($1, $1);
+      /\G(SEMANTIC)/gc and return ($1, $1);
+      /\G(STAR)/gc and return ($1, $1);
+      /\G(START)/gc and return ($1, $1);
+      /\G(STRICT)/gc and return ($1, $1);
+      /\G(SYNTACTIC)/gc and return ($1, $1);
+      /\G(TAILCODE)/gc and return ($1, $1);
+      /\G(TOKEN)/gc and return ($1, $1);
+      /\G(TREE)/gc and return ($1, $1);
+      /\G(TYPE)/gc and return ($1, $1);
+      /\G(UNION)/gc and return ($1, $1);
+
+
+      return ('', undef) if ($_ eq '') || (defined(pos($_)) && (pos($_) >= length($_)));
+      /\G\s*(\S+)/;
+      my $near = substr($1,0,10); 
+
+      return($near, $near);
+
+     # die( "Error inside the lexical analyzer near '". $near
+     #     ."'. Line: ".$self->line()
+     #     .". File: '".$self->YYFilename()."'. No match found.\n");
+    }
+  }
+;
 
 
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
@@ -360,7 +427,7 @@ sub new {
 
   warn $warnmessage unless __PACKAGE__->isa('Parse::Eyapp::Driver'); 
   my($self)=$class->SUPER::new( 
-    yyversion => '1.182',
+    yyversion => '1.2',
     yyGRAMMAR  =>
 [#[productionNameAndLabel => lhs, [ rhs], bypass]]
   [ '_SUPERSTART' => '$start', [ 'eyapp', '$end' ], 0 ],
@@ -647,39 +714,39 @@ sub new {
 [
 	{#State 0
 		ACTIONS => {
-			'SEMANTIC' => 1,
-			'WHITES' => 2,
-			'LEXER' => 3,
-			'UNION' => 6,
-			'DUMMY' => 7,
-			'START' => 8,
-			'NAMINGSCHEME' => 10,
-			'error' => 11,
-			'DEFAULTACTION' => 12,
-			'ASSOC' => 13,
-			'EXPLORER' => 14,
-			'CONFLICT' => 15,
-			'INCREMENTAL' => 16,
-			'TREE' => 17,
-			'NOCOMPACT' => 19,
+			'SYNTACTIC' => 6,
+			'INCREMENTAL' => 5,
+			'error' => 3,
 			"%%" => -11,
-			"\n" => 22,
-			'METATREE' => 21,
-			'EXPECT' => 20,
-			'SYNTACTIC' => 23,
-			'TYPE' => 24,
-			'PREFIX' => 26,
-			'STRICT' => 27,
-			'TOKEN' => 28,
-			'EXPECTRR' => 29,
-			'HEADCODE' => 30
+			'ASSOC' => 1,
+			'HEADCODE' => 2,
+			'TREE' => 15,
+			'DEFAULTACTION' => 13,
+			'EXPECTRR' => 14,
+			'WHITES' => 16,
+			'STRICT' => 17,
+			'SEMANTIC' => 12,
+			'TOKEN' => 10,
+			'METATREE' => 11,
+			'NAMINGSCHEME' => 8,
+			'LEXER' => 7,
+			'NOCOMPACT' => 26,
+			'PREFIX' => 24,
+			'DUMMY' => 22,
+			'CONFLICT' => 18,
+			'START' => 19,
+			'EXPLORER' => 20,
+			'EXPECT' => 30,
+			'TYPE' => 29,
+			'UNION' => 28,
+			"\n" => 27
 		},
 		GOTOS => {
-			'head' => 18,
-			'decl' => 9,
-			'headsec' => 4,
-			'decls' => 25,
-			'eyapp' => 5
+			'decls' => 4,
+			'head' => 23,
+			'decl' => 25,
+			'headsec' => 21,
+			'eyapp' => 9
 		}
 	},
 	{#State 1
@@ -693,95 +760,120 @@ sub new {
 	},
 	{#State 2
 		ACTIONS => {
-			'REGEXP' => 35,
-			'CODE' => 33,
-			"=" => 34
+			"\n" => 33
 		}
 	},
 	{#State 3
 		ACTIONS => {
-			'CODE' => 36
+			"\n" => 34
 		}
 	},
 	{#State 4
 		ACTIONS => {
-			"%%" => 37
+			'METATREE' => 11,
+			'TOKEN' => 10,
+			'SEMANTIC' => 12,
+			'EXPECTRR' => 14,
+			'DEFAULTACTION' => 13,
+			'TREE' => 15,
+			'STRICT' => 17,
+			'WHITES' => 16,
+			'LEXER' => 7,
+			'NAMINGSCHEME' => 8,
+			'error' => 3,
+			'INCREMENTAL' => 5,
+			'SYNTACTIC' => 6,
+			'HEADCODE' => 2,
+			"%%" => -12,
+			'ASSOC' => 1,
+			'TYPE' => 29,
+			'EXPECT' => 30,
+			"\n" => 27,
+			'UNION' => 28,
+			'PREFIX' => 24,
+			'NOCOMPACT' => 26,
+			'CONFLICT' => 18,
+			'START' => 19,
+			'EXPLORER' => 20,
+			'DUMMY' => 22
+		},
+		GOTOS => {
+			'decl' => 35
 		}
 	},
 	{#State 5
 		ACTIONS => {
-			'' => 38
+			'LITERAL' => 37,
+			"\n" => 36
 		}
 	},
 	{#State 6
 		ACTIONS => {
-			'CODE' => 39
+			"<" => 31
+		},
+		DEFAULT => -52,
+		GOTOS => {
+			'typedecl' => 38
 		}
 	},
 	{#State 7
 		ACTIONS => {
-			"<" => 31
-		},
-		DEFAULT => -52,
-		GOTOS => {
-			'typedecl' => 40
+			'CODE' => 39
 		}
 	},
 	{#State 8
 		ACTIONS => {
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'ident' => 42
+			'CODE' => 40
 		}
 	},
 	{#State 9
-		DEFAULT => -14
+		ACTIONS => {
+			'' => 41
+		}
 	},
 	{#State 10
-		ACTIONS => {
-			'CODE' => 43
-		}
-	},
-	{#State 11
-		ACTIONS => {
-			"\n" => 44
-		}
-	},
-	{#State 12
-		ACTIONS => {
-			'CODE' => 45
-		}
-	},
-	{#State 13
 		ACTIONS => {
 			"<" => 31
 		},
 		DEFAULT => -52,
 		GOTOS => {
-			'typedecl' => 46
+			'typedecl' => 42
+		}
+	},
+	{#State 11
+		ACTIONS => {
+			"\n" => 43
+		}
+	},
+	{#State 12
+		ACTIONS => {
+			"<" => 31
+		},
+		DEFAULT => -52,
+		GOTOS => {
+			'typedecl' => 44
+		}
+	},
+	{#State 13
+		ACTIONS => {
+			'CODE' => 45
 		}
 	},
 	{#State 14
 		ACTIONS => {
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'ident' => 47
+			'NUMBER' => 46
 		}
 	},
 	{#State 15
 		ACTIONS => {
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'ident' => 48
+			"\n" => 47
 		}
 	},
 	{#State 16
 		ACTIONS => {
-			"\n" => 50,
-			'LITERAL' => 49
+			'CODE' => 50,
+			"=" => 48,
+			'REGEXP' => 49
 		}
 	},
 	{#State 17
@@ -791,112 +883,87 @@ sub new {
 	},
 	{#State 18
 		ACTIONS => {
-			"%%" => 56,
-			'error' => 54,
 			'IDENT' => 52
 		},
 		GOTOS => {
-			'body' => 53,
-			'rulesec' => 57,
-			'startrules' => 55
+			'ident' => 53
 		}
 	},
 	{#State 19
 		ACTIONS => {
-			"\n" => 58
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'ident' => 54
 		}
 	},
 	{#State 20
 		ACTIONS => {
-			'NUMBER' => 59
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'ident' => 55
 		}
 	},
 	{#State 21
 		ACTIONS => {
-			"\n" => 60
+			"%%" => 56
 		}
 	},
 	{#State 22
-		DEFAULT => -15
-	},
-	{#State 23
 		ACTIONS => {
 			"<" => 31
 		},
 		DEFAULT => -52,
 		GOTOS => {
-			'typedecl' => 61
+			'typedecl' => 57
+		}
+	},
+	{#State 23
+		ACTIONS => {
+			'IDENT' => 59,
+			"%%" => 61,
+			'error' => 62
+		},
+		GOTOS => {
+			'rulesec' => 60,
+			'body' => 58,
+			'startrules' => 63
 		}
 	},
 	{#State 24
-		ACTIONS => {
-			"<" => 31
-		},
-		DEFAULT => -52,
-		GOTOS => {
-			'typedecl' => 62
-		}
-	},
-	{#State 25
-		ACTIONS => {
-			'SEMANTIC' => 1,
-			'WHITES' => 2,
-			'LEXER' => 3,
-			'UNION' => 6,
-			'DUMMY' => 7,
-			'START' => 8,
-			'NAMINGSCHEME' => 10,
-			'error' => 11,
-			'DEFAULTACTION' => 12,
-			'ASSOC' => 13,
-			'EXPLORER' => 14,
-			'CONFLICT' => 15,
-			'INCREMENTAL' => 16,
-			'TREE' => 17,
-			'NOCOMPACT' => 19,
-			"%%" => -12,
-			"\n" => 22,
-			'METATREE' => 21,
-			'EXPECT' => 20,
-			'SYNTACTIC' => 23,
-			'TYPE' => 24,
-			'PREFIX' => 26,
-			'STRICT' => 27,
-			'TOKEN' => 28,
-			'EXPECTRR' => 29,
-			'HEADCODE' => 30
-		},
-		GOTOS => {
-			'decl' => 63
-		}
-	},
-	{#State 26
 		ACTIONS => {
 			"\n" => 64
 		}
 	},
-	{#State 27
+	{#State 25
+		DEFAULT => -14
+	},
+	{#State 26
 		ACTIONS => {
 			"\n" => 65
 		}
 	},
+	{#State 27
+		DEFAULT => -15
+	},
 	{#State 28
+		ACTIONS => {
+			'CODE' => 66
+		}
+	},
+	{#State 29
 		ACTIONS => {
 			"<" => 31
 		},
 		DEFAULT => -52,
 		GOTOS => {
-			'typedecl' => 66
-		}
-	},
-	{#State 29
-		ACTIONS => {
-			'NUMBER' => 67
+			'typedecl' => 67
 		}
 	},
 	{#State 30
 		ACTIONS => {
-			"\n" => 68
+			'NUMBER' => 68
 		}
 	},
 	{#State 31
@@ -906,221 +973,221 @@ sub new {
 	},
 	{#State 32
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
+			'LITERAL' => 70,
+			'IDENT' => 52
 		},
 		GOTOS => {
-			'tokendef' => 70,
-			'toklist' => 73,
-			'symbol' => 72,
-			'ident' => 74
+			'symlist' => 73,
+			'ident' => 71,
+			'symbol' => 72
 		}
 	},
 	{#State 33
-		ACTIONS => {
-			"\n" => 75
-		}
+		DEFAULT => -28
 	},
 	{#State 34
-		ACTIONS => {
-			'REGEXP' => 77,
-			'CODE' => 76
-		}
+		DEFAULT => -49
 	},
 	{#State 35
-		ACTIONS => {
-			"\n" => 78
-		}
+		DEFAULT => -13
 	},
 	{#State 36
+		DEFAULT => -31
+	},
+	{#State 37
+		ACTIONS => {
+			"\n" => 74
+		}
+	},
+	{#State 38
+		ACTIONS => {
+			'IDENT' => 52,
+			'LITERAL' => 70
+		},
+		GOTOS => {
+			'tokendef' => 77,
+			'ident' => 75,
+			'toklist' => 78,
+			'symbol' => 76
+		}
+	},
+	{#State 39
 		ACTIONS => {
 			"\n" => 79
 		}
 	},
-	{#State 37
-		DEFAULT => -8
-	},
-	{#State 38
-		DEFAULT => 0
-	},
-	{#State 39
+	{#State 40
 		ACTIONS => {
 			"\n" => 80
 		}
 	},
-	{#State 40
-		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'tokendef' => 70,
-			'toklist' => 81,
-			'symbol' => 72,
-			'ident' => 74
-		}
-	},
 	{#State 41
-		DEFAULT => -4
+		DEFAULT => 0
 	},
 	{#State 42
 		ACTIONS => {
-			"\n" => 82
+			'LITERAL' => 70,
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'symbol' => 76,
+			'tokendef' => 77,
+			'ident' => 75,
+			'toklist' => 81
 		}
 	},
 	{#State 43
+		DEFAULT => -35
+	},
+	{#State 44
+		ACTIONS => {
+			'LITERAL' => 70,
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'symbol' => 76,
+			'toklist' => 82,
+			'ident' => 75,
+			'tokendef' => 77
+		}
+	},
+	{#State 45
 		ACTIONS => {
 			"\n" => 83
 		}
 	},
-	{#State 44
-		DEFAULT => -49
-	},
-	{#State 45
+	{#State 46
 		ACTIONS => {
 			"\n" => 84
 		}
 	},
-	{#State 46
-		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'symlist' => 87,
-			'symbol' => 85,
-			'ident' => 86
-		}
-	},
 	{#State 47
-		ACTIONS => {
-			'CODE' => 90,
-			'LITERAL' => 89,
-			'IDENT' => 88
-		},
-		GOTOS => {
-			'perlident' => 91
-		}
+		DEFAULT => -34
 	},
 	{#State 48
 		ACTIONS => {
-			"!" => 92,
-			'CODE' => 94,
-			'IDENT' => 88
-		},
-		DEFAULT => -50,
-		GOTOS => {
-			'perlident' => 95,
-			'neg' => 93
+			'REGEXP' => 86,
+			'CODE' => 85
 		}
 	},
 	{#State 49
 		ACTIONS => {
-			"\n" => 96
+			"\n" => 87
 		}
 	},
 	{#State 50
-		DEFAULT => -31
+		ACTIONS => {
+			"\n" => 88
+		}
 	},
 	{#State 51
-		DEFAULT => -34
+		DEFAULT => -36
 	},
 	{#State 52
-		ACTIONS => {
-			":" => 97
-		}
+		DEFAULT => -4
 	},
 	{#State 53
 		ACTIONS => {
-			'TAILCODE' => 99
+			"!" => 91,
+			'CODE' => 92,
+			'IDENT' => 89
 		},
-		DEFAULT => -106,
+		DEFAULT => -50,
 		GOTOS => {
-			'tail' => 98
+			'neg' => 93,
+			'perlident' => 90
 		}
 	},
 	{#State 54
 		ACTIONS => {
-			";" => 100
+			"\n" => 94
 		}
 	},
 	{#State 55
-		DEFAULT => -69
+		ACTIONS => {
+			'LITERAL' => 97,
+			'IDENT' => 89,
+			'CODE' => 95
+		},
+		GOTOS => {
+			'perlident' => 96
+		}
 	},
 	{#State 56
-		DEFAULT => -67
+		DEFAULT => -8
 	},
 	{#State 57
 		ACTIONS => {
-			"%%" => 104,
-			'error' => 103,
-			'IDENT' => 101
+			'IDENT' => 52,
+			'LITERAL' => 70
 		},
 		GOTOS => {
-			'rules' => 102
+			'symbol' => 76,
+			'toklist' => 98,
+			'tokendef' => 77,
+			'ident' => 75
 		}
 	},
 	{#State 58
-		DEFAULT => -37
+		ACTIONS => {
+			'TAILCODE' => 100
+		},
+		DEFAULT => -106,
+		GOTOS => {
+			'tail' => 99
+		}
 	},
 	{#State 59
 		ACTIONS => {
-			"\n" => 106,
-			'NUMBER' => 105
+			":" => 101
 		}
 	},
 	{#State 60
-		DEFAULT => -35
-	},
-	{#State 61
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
+			"%%" => 103,
+			'IDENT' => 104,
+			'error' => 102
 		},
 		GOTOS => {
-			'tokendef' => 70,
-			'toklist' => 107,
-			'symbol' => 72,
-			'ident' => 74
+			'rules' => 105
 		}
 	},
+	{#State 61
+		DEFAULT => -67
+	},
 	{#State 62
 		ACTIONS => {
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'identlist' => 108,
-			'ident' => 109
+			";" => 106
 		}
 	},
 	{#State 63
-		DEFAULT => -13
+		DEFAULT => -69
 	},
 	{#State 64
 		DEFAULT => -22
 	},
 	{#State 65
-		DEFAULT => -36
+		DEFAULT => -37
 	},
 	{#State 66
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'tokendef' => 70,
-			'toklist' => 110,
-			'symbol' => 72,
-			'ident' => 74
+			"\n" => 107
 		}
 	},
 	{#State 67
 		ACTIONS => {
-			"\n" => 111
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'ident' => 108,
+			'identlist' => 109
 		}
 	},
 	{#State 68
-		DEFAULT => -28
+		ACTIONS => {
+			'NUMBER' => 110,
+			"\n" => 111
+		}
 	},
 	{#State 69
 		ACTIONS => {
@@ -1128,309 +1195,309 @@ sub new {
 		}
 	},
 	{#State 70
-		DEFAULT => -57
-	},
-	{#State 71
 		DEFAULT => -2
 	},
+	{#State 71
+		DEFAULT => -3
+	},
 	{#State 72
-		DEFAULT => -63
+		DEFAULT => -55
 	},
 	{#State 73
 		ACTIONS => {
-			"\n" => 114,
-			'LITERAL' => 71,
-			'IDENT' => 41
+			'LITERAL' => 70,
+			'IDENT' => 52,
+			"\n" => 113
 		},
 		GOTOS => {
-			'tokendef' => 113,
-			'symbol' => 72,
-			'ident' => 74
+			'ident' => 71,
+			'symbol' => 114
 		}
 	},
 	{#State 74
+		DEFAULT => -32
+	},
+	{#State 75
 		ACTIONS => {
 			"=" => 115
 		},
 		DEFAULT => -3
 	},
-	{#State 75
-		DEFAULT => -23
-	},
 	{#State 76
-		ACTIONS => {
-			"\n" => 116
-		}
+		DEFAULT => -63
 	},
 	{#State 77
-		ACTIONS => {
-			"\n" => 117
-		}
+		DEFAULT => -57
 	},
 	{#State 78
-		DEFAULT => -24
+		ACTIONS => {
+			'LITERAL' => 70,
+			"\n" => 117,
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'symbol' => 76,
+			'ident' => 75,
+			'tokendef' => 116
+		}
 	},
 	{#State 79
 		DEFAULT => -33
 	},
 	{#State 80
-		DEFAULT => -29
+		DEFAULT => -27
 	},
 	{#State 81
 		ACTIONS => {
-			"\n" => 118,
-			'LITERAL' => 71,
-			'IDENT' => 41
+			'LITERAL' => 70,
+			'IDENT' => 52,
+			"\n" => 118
 		},
 		GOTOS => {
-			'tokendef' => 113,
-			'symbol' => 72,
-			'ident' => 74
+			'symbol' => 76,
+			'tokendef' => 116,
+			'ident' => 75
 		}
 	},
 	{#State 82
-		DEFAULT => -21
-	},
-	{#State 83
-		DEFAULT => -27
-	},
-	{#State 84
-		DEFAULT => -30
-	},
-	{#State 85
-		DEFAULT => -55
-	},
-	{#State 86
-		DEFAULT => -3
-	},
-	{#State 87
 		ACTIONS => {
-			"\n" => 120,
-			'LITERAL' => 71,
-			'IDENT' => 41
+			'LITERAL' => 70,
+			'IDENT' => 52,
+			"\n" => 119
 		},
 		GOTOS => {
-			'symbol' => 119,
-			'ident' => 86
+			'symbol' => 76,
+			'ident' => 75,
+			'tokendef' => 116
 		}
 	},
-	{#State 88
-		DEFAULT => -9
+	{#State 83
+		DEFAULT => -30
 	},
-	{#State 89
+	{#State 84
+		DEFAULT => -48
+	},
+	{#State 85
+		ACTIONS => {
+			"\n" => 120
+		}
+	},
+	{#State 86
 		ACTIONS => {
 			"\n" => 121
 		}
 	},
+	{#State 87
+		DEFAULT => -24
+	},
+	{#State 88
+		DEFAULT => -23
+	},
+	{#State 89
+		DEFAULT => -9
+	},
 	{#State 90
 		ACTIONS => {
-			"\n" => 122
+			"::" => 123,
+			"?" => 122
 		}
 	},
 	{#State 91
-		ACTIONS => {
-			"::" => 123,
-			"\n" => 125,
-			'LITERAL' => 124
-		}
+		DEFAULT => -51
 	},
 	{#State 92
-		DEFAULT => -51
+		ACTIONS => {
+			"\n" => 124
+		}
 	},
 	{#State 93
 		ACTIONS => {
-			'REGEXP' => 126
+			'REGEXP' => 125
 		}
 	},
 	{#State 94
-		ACTIONS => {
-			"\n" => 127
-		}
+		DEFAULT => -21
 	},
 	{#State 95
 		ACTIONS => {
-			"::" => 123,
-			"?" => 128
+			"\n" => 126
 		}
 	},
 	{#State 96
-		DEFAULT => -32
+		ACTIONS => {
+			"\n" => 128,
+			"::" => 123,
+			'LITERAL' => 127
+		}
 	},
 	{#State 97
-		DEFAULT => -71,
-		GOTOS => {
-			'@70-2' => 129
+		ACTIONS => {
+			"\n" => 129
 		}
 	},
 	{#State 98
-		DEFAULT => -1
+		ACTIONS => {
+			'LITERAL' => 70,
+			'IDENT' => 52,
+			"\n" => 130
+		},
+		GOTOS => {
+			'symbol' => 76,
+			'ident' => 75,
+			'tokendef' => 116
+		}
 	},
 	{#State 99
-		DEFAULT => -107
+		DEFAULT => -1
 	},
 	{#State 100
-		DEFAULT => -72
+		DEFAULT => -107
 	},
 	{#State 101
-		ACTIONS => {
-			":" => 130
+		DEFAULT => -71,
+		GOTOS => {
+			'@70-2' => 131
 		}
 	},
 	{#State 102
-		DEFAULT => -68
+		ACTIONS => {
+			";" => 132
+		}
 	},
 	{#State 103
-		ACTIONS => {
-			";" => 131
-		}
-	},
-	{#State 104
 		DEFAULT => -66
 	},
-	{#State 105
+	{#State 104
 		ACTIONS => {
-			"\n" => 132
+			":" => 133
 		}
 	},
+	{#State 105
+		DEFAULT => -68
+	},
 	{#State 106
-		DEFAULT => -46
+		DEFAULT => -72
 	},
 	{#State 107
-		ACTIONS => {
-			"\n" => 133,
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'tokendef' => 113,
-			'symbol' => 72,
-			'ident' => 74
-		}
+		DEFAULT => -29
 	},
 	{#State 108
+		DEFAULT => -65
+	},
+	{#State 109
 		ACTIONS => {
 			"\n" => 134,
-			'IDENT' => 41
+			'IDENT' => 52
 		},
 		GOTOS => {
 			'ident' => 135
 		}
 	},
-	{#State 109
-		DEFAULT => -65
-	},
 	{#State 110
 		ACTIONS => {
-			"\n" => 136,
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'tokendef' => 113,
-			'symbol' => 72,
-			'ident' => 74
+			"\n" => 136
 		}
 	},
 	{#State 111
-		DEFAULT => -48
+		DEFAULT => -46
 	},
 	{#State 112
 		DEFAULT => -53
 	},
 	{#State 113
-		DEFAULT => -56
+		DEFAULT => -20
 	},
 	{#State 114
-		DEFAULT => -16
+		DEFAULT => -54
 	},
 	{#State 115
 		ACTIONS => {
-			'REGEXP' => 139,
 			'CODE' => 138,
-			"%" => 137
+			'REGEXP' => 137,
+			"%" => 139
 		}
 	},
 	{#State 116
-		DEFAULT => -25
+		DEFAULT => -56
 	},
 	{#State 117
-		DEFAULT => -26
+		DEFAULT => -17
 	},
 	{#State 118
-		DEFAULT => -18
+		DEFAULT => -19
 	},
 	{#State 119
-		DEFAULT => -54
+		DEFAULT => -16
 	},
 	{#State 120
-		DEFAULT => -20
+		DEFAULT => -25
 	},
 	{#State 121
-		DEFAULT => -43
+		DEFAULT => -26
 	},
 	{#State 122
-		DEFAULT => -42
+		ACTIONS => {
+			'IDENT' => 140,
+			'LABEL' => 141
+		},
+		GOTOS => {
+			'prodname' => 142
+		}
 	},
 	{#State 123
 		ACTIONS => {
-			'IDENT' => 140
+			'IDENT' => 143
 		}
 	},
 	{#State 124
-		ACTIONS => {
-			"\n" => 141
-		}
-	},
-	{#State 125
-		DEFAULT => -44
-	},
-	{#State 126
-		ACTIONS => {
-			"?" => 142
-		}
-	},
-	{#State 127
 		DEFAULT => -39
 	},
-	{#State 128
+	{#State 125
 		ACTIONS => {
-			'LABEL' => 143,
-			'IDENT' => 144
-		},
-		GOTOS => {
-			'prodname' => 145
+			"?" => 144
 		}
 	},
+	{#State 126
+		DEFAULT => -42
+	},
+	{#State 127
+		ACTIONS => {
+			"\n" => 145
+		}
+	},
+	{#State 128
+		DEFAULT => -44
+	},
 	{#State 129
-		ACTIONS => {
-			'NAME' => 149
-		},
-		DEFAULT => -97,
-		GOTOS => {
-			'rule' => 146,
-			'rhss' => 148,
-			'optname' => 147
-		}
+		DEFAULT => -43
 	},
 	{#State 130
+		DEFAULT => -18
+	},
+	{#State 131
 		ACTIONS => {
-			'NAME' => 149
+			'NAME' => 147
 		},
 		DEFAULT => -97,
 		GOTOS => {
-			'rule' => 146,
-			'rhss' => 150,
-			'optname' => 147
+			'rule' => 148,
+			'rhss' => 149,
+			'optname' => 146
 		}
 	},
-	{#State 131
+	{#State 132
 		DEFAULT => -74
 	},
-	{#State 132
-		DEFAULT => -47
-	},
 	{#State 133
-		DEFAULT => -17
+		ACTIONS => {
+			'NAME' => 147
+		},
+		DEFAULT => -97,
+		GOTOS => {
+			'rule' => 148,
+			'rhss' => 150,
+			'optname' => 146
+		}
 	},
 	{#State 134
 		DEFAULT => -38
@@ -1439,228 +1506,228 @@ sub new {
 		DEFAULT => -64
 	},
 	{#State 136
-		DEFAULT => -19
+		DEFAULT => -47
 	},
 	{#State 137
-		ACTIONS => {
-			'REGEXP' => 151
-		}
+		DEFAULT => -58
 	},
 	{#State 138
 		DEFAULT => -62
 	},
 	{#State 139
-		DEFAULT => -58
-	},
-	{#State 140
-		DEFAULT => -10
-	},
-	{#State 141
-		DEFAULT => -45
-	},
-	{#State 142
 		ACTIONS => {
-			'LABEL' => 143,
-			'IDENT' => 144
-		},
-		GOTOS => {
-			'prodname' => 152
+			'REGEXP' => 151
 		}
 	},
-	{#State 143
-		DEFAULT => -6
-	},
-	{#State 144
+	{#State 140
 		ACTIONS => {
-			'LABEL' => 153
+			'LABEL' => 152
 		},
 		DEFAULT => -5
 	},
-	{#State 145
+	{#State 141
+		DEFAULT => -6
+	},
+	{#State 142
 		ACTIONS => {
-			":" => 154
+			":" => 153
 		}
 	},
-	{#State 146
-		DEFAULT => -76
+	{#State 143
+		DEFAULT => -10
 	},
-	{#State 147
+	{#State 144
 		ACTIONS => {
+			'IDENT' => 140,
+			'LABEL' => 141
+		},
+		GOTOS => {
+			'prodname' => 154
+		}
+	},
+	{#State 145
+		DEFAULT => -45
+	},
+	{#State 146
+		ACTIONS => {
+			'BEGINCODE' => 157,
+			"(" => 162,
+			'LITERAL' => 70,
+			"\$" => 155,
+			'VIEWPOINT' => 161,
 			'CODE' => 164,
-			'LITERAL' => 71,
-			'IDENT' => 41,
-			'BEGINCODE' => 156,
-			"(" => 165,
-			'DPREC' => 166,
-			'VIEWPOINT' => 158,
-			"\$" => 159
+			'IDENT' => 52,
+			'DPREC' => 158
 		},
 		DEFAULT => -79,
 		GOTOS => {
-			'symbol' => 163,
-			'rhselt' => 157,
-			'rhs' => 155,
-			'rhselts' => 161,
-			'rhseltwithid' => 160,
-			'ident' => 86,
-			'code' => 162
+			'rhseltwithid' => 163,
+			'ident' => 71,
+			'rhselts' => 166,
+			'rhselt' => 165,
+			'rhs' => 160,
+			'symbol' => 159,
+			'code' => 156
+		}
+	},
+	{#State 147
+		ACTIONS => {
+			'IDENT' => 167,
+			'LABEL' => 168
 		}
 	},
 	{#State 148
-		ACTIONS => {
-			"|" => 168,
-			";" => 167
-		}
+		DEFAULT => -76
 	},
 	{#State 149
 		ACTIONS => {
-			'LABEL' => 169,
-			'IDENT' => 170
+			"|" => 170,
+			";" => 169
 		}
 	},
 	{#State 150
 		ACTIONS => {
-			"|" => 168,
-			";" => 171
+			";" => 171,
+			"|" => 170
 		}
 	},
 	{#State 151
 		ACTIONS => {
-			"!" => 172,
-			"=" => 173
+			"=" => 173,
+			"!" => 172
 		},
 		DEFAULT => -59
 	},
 	{#State 152
-		ACTIONS => {
-			":" => 174
-		}
+		DEFAULT => -7
 	},
 	{#State 153
-		DEFAULT => -7
+		ACTIONS => {
+			'IDENT' => 140,
+			'LABEL' => 141
+		},
+		GOTOS => {
+			'prodname' => 174
+		}
 	},
 	{#State 154
 		ACTIONS => {
-			'LABEL' => 143,
-			'IDENT' => 144
-		},
-		GOTOS => {
-			'prodname' => 175
+			":" => 175
 		}
 	},
 	{#State 155
 		ACTIONS => {
-			'PREC' => 176
+			'LITERAL' => 70,
+			'BEGINCODE' => 157,
+			"(" => 162,
+			'VIEWPOINT' => 161,
+			'error' => 177,
+			'IDENT' => 52,
+			'DPREC' => 158,
+			'CODE' => 164
 		},
-		DEFAULT => -78,
 		GOTOS => {
-			'prec' => 177
+			'rhselt' => 176,
+			'ident' => 71,
+			'code' => 156,
+			'symbol' => 159
 		}
 	},
 	{#State 156
-		DEFAULT => -105
-	},
-	{#State 157
-		ACTIONS => {
-			"<" => 178,
-			'PLUS' => 179,
-			'OPTION' => 180,
-			'STAR' => 181,
-			"." => 182
-		},
-		DEFAULT => -86
-	},
-	{#State 158
-		DEFAULT => -90
-	},
-	{#State 159
-		ACTIONS => {
-			"(" => 165,
-			'DPREC' => 166,
-			'VIEWPOINT' => 158,
-			'error' => 184,
-			'CODE' => 164,
-			'LITERAL' => 71,
-			'IDENT' => 41,
-			'BEGINCODE' => 156
-		},
-		GOTOS => {
-			'symbol' => 163,
-			'rhselt' => 183,
-			'ident' => 86,
-			'code' => 162
-		}
-	},
-	{#State 160
-		DEFAULT => -82
-	},
-	{#State 161
-		ACTIONS => {
-			'CODE' => 164,
-			'LITERAL' => 71,
-			'IDENT' => 41,
-			'BEGINCODE' => 156,
-			"(" => 165,
-			'DPREC' => 166,
-			'VIEWPOINT' => 158,
-			"\$" => 159
-		},
-		DEFAULT => -80,
-		GOTOS => {
-			'symbol' => 163,
-			'rhselt' => 157,
-			'rhseltwithid' => 185,
-			'ident' => 86,
-			'code' => 162
-		}
-	},
-	{#State 162
 		DEFAULT => -88
 	},
-	{#State 163
+	{#State 157
+		DEFAULT => -105
+	},
+	{#State 158
+		ACTIONS => {
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'ident' => 178
+		}
+	},
+	{#State 159
 		DEFAULT => -87
 	},
+	{#State 160
+		ACTIONS => {
+			'PREC' => 180
+		},
+		DEFAULT => -78,
+		GOTOS => {
+			'prec' => 179
+		}
+	},
+	{#State 161
+		DEFAULT => -90
+	},
+	{#State 162
+		ACTIONS => {
+			'NAME' => 147
+		},
+		DEFAULT => -97,
+		GOTOS => {
+			'optname' => 181
+		}
+	},
+	{#State 163
+		DEFAULT => -82
+	},
 	{#State 164
 		DEFAULT => -104
 	},
 	{#State 165
 		ACTIONS => {
-			'NAME' => 149
+			'OPTION' => 183,
+			'STAR' => 182,
+			"." => 185,
+			"<" => 184,
+			'PLUS' => 186
 		},
-		DEFAULT => -97,
-		GOTOS => {
-			'optname' => 186
-		}
+		DEFAULT => -86
 	},
 	{#State 166
 		ACTIONS => {
-			'IDENT' => 41
+			'VIEWPOINT' => 161,
+			'IDENT' => 52,
+			'DPREC' => 158,
+			'CODE' => 164,
+			'LITERAL' => 70,
+			'BEGINCODE' => 157,
+			"(" => 162,
+			"\$" => 155
 		},
+		DEFAULT => -80,
 		GOTOS => {
-			'ident' => 187
+			'code' => 156,
+			'symbol' => 159,
+			'ident' => 71,
+			'rhseltwithid' => 187,
+			'rhselt' => 165
 		}
 	},
 	{#State 167
-		DEFAULT => -70
+		ACTIONS => {
+			'LABEL' => 188
+		},
+		DEFAULT => -98
 	},
 	{#State 168
-		ACTIONS => {
-			'NAME' => 149
-		},
-		DEFAULT => -97,
-		GOTOS => {
-			'rule' => 188,
-			'optname' => 147
-		}
+		DEFAULT => -100
 	},
 	{#State 169
-		DEFAULT => -100
+		DEFAULT => -70
 	},
 	{#State 170
 		ACTIONS => {
-			'LABEL' => 189
+			'NAME' => 147
 		},
-		DEFAULT => -98
+		DEFAULT => -97,
+		GOTOS => {
+			'optname' => 146,
+			'rule' => 189
+		}
 	},
 	{#State 171
 		DEFAULT => -73
@@ -1677,104 +1744,104 @@ sub new {
 	},
 	{#State 174
 		ACTIONS => {
-			'LABEL' => 143,
-			'IDENT' => 144
-		},
-		GOTOS => {
-			'prodname' => 192
+			"\n" => 192
 		}
 	},
 	{#State 175
 		ACTIONS => {
-			"\n" => 193
+			'IDENT' => 140,
+			'LABEL' => 141
+		},
+		GOTOS => {
+			'prodname' => 193
 		}
 	},
 	{#State 176
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'symbol' => 194,
-			'ident' => 86
-		}
-	},
-	{#State 177
-		ACTIONS => {
-			'CODE' => 164,
-			'BEGINCODE' => 156
-		},
-		DEFAULT => -102,
-		GOTOS => {
-			'epscode' => 196,
-			'code' => 195
-		}
-	},
-	{#State 178
-		ACTIONS => {
-			'STAR' => 198,
-			'PLUS' => 197
-		}
-	},
-	{#State 179
-		DEFAULT => -96
-	},
-	{#State 180
-		DEFAULT => -94
-	},
-	{#State 181
-		DEFAULT => -92
-	},
-	{#State 182
-		ACTIONS => {
-			'IDENT' => 199
-		}
-	},
-	{#State 183
-		ACTIONS => {
-			"<" => 178,
-			'PLUS' => 179,
-			'OPTION' => 180,
-			'STAR' => 181
+			"<" => 184,
+			'PLUS' => 186,
+			'STAR' => 182,
+			'OPTION' => 183
 		},
 		DEFAULT => -84
 	},
-	{#State 184
+	{#State 177
 		DEFAULT => -85
 	},
-	{#State 185
-		DEFAULT => -81
+	{#State 178
+		DEFAULT => -89
 	},
-	{#State 186
+	{#State 179
 		ACTIONS => {
-			"(" => 165,
-			'DPREC' => 166,
-			"\$" => 159,
-			'VIEWPOINT' => 158,
 			'CODE' => 164,
-			'LITERAL' => 71,
-			'IDENT' => 41,
-			'BEGINCODE' => 156
+			'BEGINCODE' => 157
+		},
+		DEFAULT => -102,
+		GOTOS => {
+			'code' => 194,
+			'epscode' => 195
+		}
+	},
+	{#State 180
+		ACTIONS => {
+			'IDENT' => 52,
+			'LITERAL' => 70
+		},
+		GOTOS => {
+			'symbol' => 196,
+			'ident' => 71
+		}
+	},
+	{#State 181
+		ACTIONS => {
+			'VIEWPOINT' => 161,
+			'CODE' => 164,
+			'IDENT' => 52,
+			'DPREC' => 158,
+			'BEGINCODE' => 157,
+			"(" => 162,
+			'LITERAL' => 70,
+			"\$" => 155
 		},
 		DEFAULT => -79,
 		GOTOS => {
-			'symbol' => 163,
-			'rhselt' => 157,
-			'rhs' => 200,
-			'rhselts' => 161,
-			'rhseltwithid' => 160,
-			'ident' => 86,
-			'code' => 162
+			'symbol' => 159,
+			'code' => 156,
+			'rhs' => 197,
+			'rhselts' => 166,
+			'rhselt' => 165,
+			'rhseltwithid' => 163,
+			'ident' => 71
 		}
 	},
+	{#State 182
+		DEFAULT => -92
+	},
+	{#State 183
+		DEFAULT => -94
+	},
+	{#State 184
+		ACTIONS => {
+			'STAR' => 198,
+			'PLUS' => 199
+		}
+	},
+	{#State 185
+		ACTIONS => {
+			'IDENT' => 200
+		}
+	},
+	{#State 186
+		DEFAULT => -96
+	},
 	{#State 187
-		DEFAULT => -89
+		DEFAULT => -81
 	},
 	{#State 188
-		DEFAULT => -75
+		DEFAULT => -99
 	},
 	{#State 189
-		DEFAULT => -99
+		DEFAULT => -75
 	},
 	{#State 190
 		DEFAULT => -61
@@ -1783,71 +1850,71 @@ sub new {
 		DEFAULT => -60
 	},
 	{#State 192
+		DEFAULT => -40
+	},
+	{#State 193
 		ACTIONS => {
 			"\n" => 201
 		}
 	},
-	{#State 193
-		DEFAULT => -40
-	},
 	{#State 194
-		DEFAULT => -101
-	},
-	{#State 195
 		DEFAULT => -103
 	},
-	{#State 196
+	{#State 195
 		DEFAULT => -77
 	},
+	{#State 196
+		DEFAULT => -101
+	},
 	{#State 197
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
-		},
-		GOTOS => {
-			'symbol' => 202,
-			'ident' => 86
+			")" => 202
 		}
 	},
 	{#State 198
 		ACTIONS => {
-			'LITERAL' => 71,
-			'IDENT' => 41
+			'LITERAL' => 70,
+			'IDENT' => 52
 		},
 		GOTOS => {
 			'symbol' => 203,
-			'ident' => 86
+			'ident' => 71
 		}
 	},
 	{#State 199
-		DEFAULT => -83
+		ACTIONS => {
+			'LITERAL' => 70,
+			'IDENT' => 52
+		},
+		GOTOS => {
+			'symbol' => 204,
+			'ident' => 71
+		}
 	},
 	{#State 200
-		ACTIONS => {
-			")" => 204
-		}
+		DEFAULT => -83
 	},
 	{#State 201
 		DEFAULT => -41
 	},
 	{#State 202
+		DEFAULT => -91
+	},
+	{#State 203
 		ACTIONS => {
 			">" => 205
 		}
 	},
-	{#State 203
+	{#State 204
 		ACTIONS => {
 			">" => 206
 		}
 	},
-	{#State 204
-		DEFAULT => -91
-	},
 	{#State 205
-		DEFAULT => -95
+		DEFAULT => -93
 	},
 	{#State 206
-		DEFAULT => -93
+		DEFAULT => -95
 	}
 ],
     yyrules  =>
@@ -3230,13 +3297,13 @@ sub _Lexer {
         return($1, [ $1, $lineno[0] ]);
     };
 
-        $$input=~/\G\s*{/gc and return ('CODE', &slurp_perl_code());  # }
+        $$input=~/\G\s*\{/gc and return ('CODE', &slurp_perl_code());  # }
 
     if($lexlevel == 0) {# In head section
 
         $$input=~/\G%(left|right|nonassoc)/gc and return('ASSOC',[ uc($1), $lineno[0] ]);
 
-            $$input=~/\G%{/gc
+            $$input=~/\G%\{/gc
         and do {
             my($code);
 
