@@ -1,9 +1,15 @@
 ########################################################################################
 #
-#    This file was generated using Parse::Eyapp version 1.182.
+#    This file was generated using Parse::Eyapp version 1.2.
+#
+# Copyright © 2006, 2007, 2008, 2009, 2010, 2011, 2012 Casiano Rodriguez-Leon.
+# Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
+#
+# Parse::Yapp is Copyright © 1998, 1999, 2000, 2001, Francois Desarmenien.
+# Parse::Yapp is Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
 #
-# (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
-# (c) Parse::Eyapp Copyright 2006-2008 Casiano Rodriguez-Leon. Universidad de La Laguna.
 #        Don't edit this file, use source file 'lib/Parse/Eyapp/Treeregexp.yp' instead.
 #
 #             ANY CHANGE MADE HERE WILL BE LOST !
@@ -229,6 +235,37 @@ sub new_array_star {
 }
 
 
+# Default lexical analyzer
+our $LEX = sub {
+    my $self = shift;
+    my $pos;
+
+    for (${$self->input}) {
+      
+
+      m{\G(\s+)}gc and $self->tokenline($1 =~ tr{\n}{});
+
+      m{\G(and|\=\>|\.|\(|\)|\,|\:|\=|\;|\*)}gc and return ($1, $1);
+
+      /\G(ARRAY)/gc and return ($1, $1);
+      /\G(SCALAR)/gc and return ($1, $1);
+      /\G(IDENT)/gc and return ($1, $1);
+      /\G(REGEXP)/gc and return ($1, $1);
+      /\G(CODE)/gc and return ($1, $1);
+
+
+      return ('', undef) if ($_ eq '') || (defined(pos($_)) && (pos($_) >= length($_)));
+      /\G\s*(\S+)/;
+      my $near = substr($1,0,10); 
+
+      return($near, $near);
+
+     # die( "Error inside the lexical analyzer near '". $near
+     #     ."'. Line: ".$self->line()
+     #     .". File: '".$self->YYFilename()."'. No match found.\n");
+    }
+  }
+;
 
 
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
@@ -243,7 +280,7 @@ sub new {
 
   warn $warnmessage unless __PACKAGE__->isa('Parse::Eyapp::Driver'); 
   my($self)=$class->SUPER::new( 
-    yyversion => '1.182',
+    yyversion => '1.2',
     yyGRAMMAR  =>
 [#[productionNameAndLabel => lhs, [ rhs], bypass]]
   [ '_SUPERSTART' => '$start', [ 'treeregexplist', '$end' ], 0 ],
@@ -391,424 +428,489 @@ sub new {
 	{#State 0
 		DEFAULT => -2,
 		GOTOS => {
-			'STAR-1' => 1,
-			'treeregexplist' => 2
+			'treeregexplist' => 1,
+			'STAR-1' => 2
 		}
 	},
 	{#State 1
 		ACTIONS => {
-			'REGEXP' => 3,
-			'IDENT' => 6,
-			'CODE' => 5
-		},
-		DEFAULT => -3,
-		GOTOS => {
-			'treeregexp' => 4
+			'' => 3
 		}
 	},
 	{#State 2
 		ACTIONS => {
-			'' => 7
+			'CODE' => 5,
+			'REGEXP' => 6,
+			'' => -3,
+			'IDENT' => 4
+		},
+		GOTOS => {
+			'treeregexp' => 7
 		}
 	},
 	{#State 3
-		DEFAULT => -12
+		DEFAULT => 0
 	},
 	{#State 4
-		DEFAULT => -1
+		ACTIONS => {
+			"=" => 8,
+			":" => 9
+		}
 	},
 	{#State 5
 		DEFAULT => -10
 	},
 	{#State 6
-		ACTIONS => {
-			":" => 8,
-			"=" => 9
-		}
+		DEFAULT => -12
 	},
 	{#State 7
-		DEFAULT => 0
+		DEFAULT => -1
 	},
 	{#State 8
 		ACTIONS => {
-			'REGEXP' => 10,
-			"*" => 11,
-			'IDENT' => 12,
-			"." => 14,
-			'ARRAY' => 13,
-			'SCALAR' => 15
+			'IDENT' => 11
 		},
 		GOTOS => {
-			'treereg' => 16
+			'PLUS-4' => 10
 		}
 	},
 	{#State 9
 		ACTIONS => {
-			'IDENT' => 17
+			"*" => 17,
+			"." => 16,
+			'REGEXP' => 15,
+			'SCALAR' => 13,
+			'IDENT' => 14,
+			'ARRAY' => 12
 		},
 		GOTOS => {
-			'PLUS-4' => 18
+			'treereg' => 18
 		}
 	},
 	{#State 10
 		ACTIONS => {
-			":" => 19,
-			"(" => -18
-		},
-		DEFAULT => -33,
-		GOTOS => {
-			'OPTIONAL-18' => 21,
-			'PAREN-17' => 20,
-			'OPTIONAL-8' => 22,
-			'PAREN-7' => 23
+			";" => 20,
+			'IDENT' => 19
 		}
 	},
 	{#State 11
-		DEFAULT => -52
+		DEFAULT => -8
 	},
 	{#State 12
-		ACTIONS => {
-			"(" => 25,
-			"and" => 26
-		},
-		DEFAULT => -30,
-		GOTOS => {
-			'PAREN-15' => 24,
-			'OPTIONAL-16' => 27
-		}
+		DEFAULT => -51
 	},
 	{#State 13
-		DEFAULT => -51
+		ACTIONS => {
+			"=>" => -39,
+			"," => -39,
+			'IDENT' => -39,
+			"(" => 24,
+			'REGEXP' => -39,
+			'CODE' => -39,
+			'' => -39,
+			"and" => 23,
+			")" => -39
+		},
+		GOTOS => {
+			'PAREN-21' => 21,
+			'OPTIONAL-22' => 22
+		}
 	},
 	{#State 14
 		ACTIONS => {
-			"(" => 28,
-			"and" => 29
+			"and" => 28,
+			'' => -30,
+			")" => -30,
+			'REGEXP' => -30,
+			'CODE' => -30,
+			'IDENT' => -30,
+			"(" => 27,
+			"=>" => -30,
+			"," => -30
 		},
-		DEFAULT => -42,
 		GOTOS => {
-			'OPTIONAL-24' => 30,
-			'PAREN-23' => 31
+			'OPTIONAL-16' => 25,
+			'PAREN-15' => 26
 		}
 	},
 	{#State 15
 		ACTIONS => {
-			"(" => 33,
-			"and" => 35
+			")" => -33,
+			"and" => -33,
+			'' => -33,
+			'CODE' => -33,
+			'REGEXP' => -33,
+			"(" => -18,
+			'IDENT' => -33,
+			"," => -33,
+			"=>" => -33,
+			":" => 29
 		},
-		DEFAULT => -39,
 		GOTOS => {
-			'OPTIONAL-22' => 32,
-			'PAREN-21' => 34
+			'OPTIONAL-8' => 31,
+			'OPTIONAL-18' => 30,
+			'PAREN-17' => 33,
+			'PAREN-7' => 32
 		}
 	},
 	{#State 16
 		ACTIONS => {
-			"=>" => 36
+			"," => -42,
+			"=>" => -42,
+			"(" => 36,
+			'IDENT' => -42,
+			'CODE' => -42,
+			'REGEXP' => -42,
+			")" => -42,
+			"and" => 35,
+			'' => -42
 		},
-		DEFAULT => -6,
 		GOTOS => {
-			'OPTIONAL-3' => 38,
-			'PAREN-2' => 37
+			'PAREN-23' => 37,
+			'OPTIONAL-24' => 34
 		}
 	},
 	{#State 17
-		DEFAULT => -8
+		DEFAULT => -52
 	},
 	{#State 18
 		ACTIONS => {
-			";" => 39,
-			'IDENT' => 40
+			"=>" => 38,
+			'REGEXP' => -6,
+			'CODE' => -6,
+			'IDENT' => -6,
+			'' => -6
+		},
+		GOTOS => {
+			'OPTIONAL-3' => 40,
+			'PAREN-2' => 39
 		}
 	},
 	{#State 19
-		ACTIONS => {
-			'IDENT' => 41
-		}
+		DEFAULT => -7
 	},
 	{#State 20
-		DEFAULT => -32
+		DEFAULT => -11
 	},
 	{#State 21
-		ACTIONS => {
-			"and" => 44
-		},
-		DEFAULT => -36,
-		GOTOS => {
-			'PAREN-19' => 42,
-			'OPTIONAL-20' => 43
-		}
+		DEFAULT => -38
 	},
 	{#State 22
-		ACTIONS => {
-			"(" => 45
-		}
+		DEFAULT => -49
 	},
 	{#State 23
-		DEFAULT => -17
+		ACTIONS => {
+			'CODE' => 41
+		}
 	},
 	{#State 24
-		DEFAULT => -29
+		ACTIONS => {
+			'ARRAY' => 12,
+			'IDENT' => 14,
+			'SCALAR' => 13,
+			"." => 16,
+			")" => -56,
+			'REGEXP' => 15,
+			"*" => 17
+		},
+		GOTOS => {
+			'STAR-26' => 45,
+			'STAR-25' => 44,
+			'childlist' => 43,
+			'treereg' => 42
+		}
 	},
 	{#State 25
-		ACTIONS => {
-			'IDENT' => 12,
-			'ARRAY' => 13,
-			'REGEXP' => 10,
-			"*" => 11,
-			"." => 14,
-			'SCALAR' => 15
-		},
-		DEFAULT => -56,
-		GOTOS => {
-			'STAR-26' => 46,
-			'STAR-25' => 48,
-			'childlist' => 47,
-			'treereg' => 49
-		}
+		DEFAULT => -47
 	},
 	{#State 26
-		ACTIONS => {
-			'CODE' => 50
-		}
+		DEFAULT => -29
 	},
 	{#State 27
-		DEFAULT => -47
+		ACTIONS => {
+			"*" => 17,
+			'REGEXP' => 15,
+			")" => -56,
+			"." => 16,
+			'SCALAR' => 13,
+			'IDENT' => 14,
+			'ARRAY' => 12
+		},
+		GOTOS => {
+			'childlist' => 46,
+			'treereg' => 42,
+			'STAR-26' => 45,
+			'STAR-25' => 44
+		}
 	},
 	{#State 28
 		ACTIONS => {
-			'IDENT' => 12,
-			'ARRAY' => 13,
-			'REGEXP' => 10,
-			"*" => 11,
-			"." => 14,
-			'SCALAR' => 15
-		},
-		DEFAULT => -56,
-		GOTOS => {
-			'STAR-26' => 46,
-			'STAR-25' => 48,
-			'childlist' => 51,
-			'treereg' => 49
+			'CODE' => 47
 		}
 	},
 	{#State 29
 		ACTIONS => {
-			'CODE' => 52
+			'IDENT' => 48
 		}
 	},
 	{#State 30
-		DEFAULT => -50
-	},
-	{#State 31
-		DEFAULT => -41
-	},
-	{#State 32
-		DEFAULT => -49
-	},
-	{#State 33
 		ACTIONS => {
-			'IDENT' => 12,
-			'ARRAY' => 13,
-			'REGEXP' => 10,
-			"*" => 11,
-			"." => 14,
-			'SCALAR' => 15
+			")" => -36,
+			"and" => 51,
+			'' => -36,
+			'CODE' => -36,
+			'REGEXP' => -36,
+			'IDENT' => -36,
+			"," => -36,
+			"=>" => -36
 		},
-		DEFAULT => -56,
 		GOTOS => {
-			'STAR-26' => 46,
-			'STAR-25' => 48,
-			'childlist' => 53,
-			'treereg' => 49
+			'PAREN-19' => 50,
+			'OPTIONAL-20' => 49
 		}
 	},
+	{#State 31
+		ACTIONS => {
+			"(" => 52
+		}
+	},
+	{#State 32
+		DEFAULT => -17
+	},
+	{#State 33
+		DEFAULT => -32
+	},
 	{#State 34
-		DEFAULT => -38
+		DEFAULT => -50
 	},
 	{#State 35
 		ACTIONS => {
-			'CODE' => 54
+			'CODE' => 53
 		}
 	},
 	{#State 36
 		ACTIONS => {
-			'CODE' => 55
+			'IDENT' => 14,
+			'SCALAR' => 13,
+			'ARRAY' => 12,
+			"." => 16,
+			")" => -56,
+			"*" => 17,
+			'REGEXP' => 15
+		},
+		GOTOS => {
+			'STAR-26' => 45,
+			'STAR-25' => 44,
+			'childlist' => 54,
+			'treereg' => 42
 		}
 	},
 	{#State 37
-		DEFAULT => -5
+		DEFAULT => -41
 	},
 	{#State 38
-		DEFAULT => -9
+		ACTIONS => {
+			'CODE' => 55
+		}
 	},
 	{#State 39
-		DEFAULT => -11
+		DEFAULT => -5
 	},
 	{#State 40
-		DEFAULT => -7
+		DEFAULT => -9
 	},
 	{#State 41
-		ACTIONS => {
-			"(" => -16
-		},
-		DEFAULT => -31
+		DEFAULT => -37
 	},
 	{#State 42
-		DEFAULT => -35
+		DEFAULT => -54
 	},
 	{#State 43
-		DEFAULT => -48
+		ACTIONS => {
+			")" => 56
+		}
 	},
 	{#State 44
 		ACTIONS => {
-			'CODE' => 56
+			")" => -55,
+			"," => 57
 		}
 	},
 	{#State 45
-		ACTIONS => {
-			'IDENT' => 12,
-			'ARRAY' => 13,
-			'REGEXP' => 10,
-			"*" => 11,
-			"." => 14,
-			'SCALAR' => 15
-		},
-		DEFAULT => -56,
-		GOTOS => {
-			'STAR-26' => 46,
-			'STAR-25' => 48,
-			'childlist' => 57,
-			'treereg' => 49
-		}
-	},
-	{#State 46
 		DEFAULT => -57
 	},
-	{#State 47
+	{#State 46
 		ACTIONS => {
 			")" => 58
 		}
 	},
+	{#State 47
+		DEFAULT => -28
+	},
 	{#State 48
 		ACTIONS => {
-			"," => 59
-		},
-		DEFAULT => -55
+			"," => -31,
+			"=>" => -31,
+			"(" => -16,
+			'IDENT' => -31,
+			'REGEXP' => -31,
+			'CODE' => -31,
+			")" => -31,
+			'' => -31,
+			"and" => -31
+		}
 	},
 	{#State 49
-		DEFAULT => -54
+		DEFAULT => -48
 	},
 	{#State 50
-		DEFAULT => -28
+		DEFAULT => -35
 	},
 	{#State 51
 		ACTIONS => {
-			")" => 60
+			'CODE' => 59
 		}
 	},
 	{#State 52
-		DEFAULT => -40
+		ACTIONS => {
+			"*" => 17,
+			'REGEXP' => 15,
+			")" => -56,
+			"." => 16,
+			'IDENT' => 14,
+			'SCALAR' => 13,
+			'ARRAY' => 12
+		},
+		GOTOS => {
+			'childlist' => 60,
+			'treereg' => 42,
+			'STAR-26' => 45,
+			'STAR-25' => 44
+		}
 	},
 	{#State 53
+		DEFAULT => -40
+	},
+	{#State 54
 		ACTIONS => {
 			")" => 61
 		}
 	},
-	{#State 54
-		DEFAULT => -37
-	},
 	{#State 55
 		DEFAULT => -4
 	},
 	{#State 56
-		DEFAULT => -34
+		ACTIONS => {
+			'REGEXP' => -24,
+			'CODE' => -24,
+			")" => -24,
+			"and" => 63,
+			'' => -24,
+			"," => -24,
+			"=>" => -24,
+			'IDENT' => -24
+		},
+		GOTOS => {
+			'PAREN-11' => 62,
+			'OPTIONAL-12' => 64
+		}
 	},
 	{#State 57
 		ACTIONS => {
-			")" => 62
+			"*" => 17,
+			"." => 16,
+			'REGEXP' => 15,
+			'IDENT' => 14,
+			'SCALAR' => 13,
+			'ARRAY' => 12
+		},
+		GOTOS => {
+			'treereg' => 65
 		}
 	},
 	{#State 58
 		ACTIONS => {
-			"and" => 65
+			'IDENT' => -15,
+			"," => -15,
+			"=>" => -15,
+			")" => -15,
+			"and" => 68,
+			'' => -15,
+			'REGEXP' => -15,
+			'CODE' => -15
 		},
-		DEFAULT => -15,
 		GOTOS => {
-			'PAREN-5' => 63,
-			'OPTIONAL-6' => 64
+			'OPTIONAL-6' => 67,
+			'PAREN-5' => 66
 		}
 	},
 	{#State 59
-		ACTIONS => {
-			'REGEXP' => 10,
-			"*" => 11,
-			'IDENT' => 12,
-			"." => 14,
-			'ARRAY' => 13,
-			'SCALAR' => 15
-		},
-		GOTOS => {
-			'treereg' => 66
-		}
+		DEFAULT => -34
 	},
 	{#State 60
 		ACTIONS => {
-			"and" => 69
-		},
-		DEFAULT => -27,
-		GOTOS => {
-			'PAREN-13' => 67,
-			'OPTIONAL-14' => 68
+			")" => 69
 		}
 	},
 	{#State 61
 		ACTIONS => {
-			"and" => 71
+			"=>" => -27,
+			"," => -27,
+			'IDENT' => -27,
+			'CODE' => -27,
+			'REGEXP' => -27,
+			'' => -27,
+			"and" => 71,
+			")" => -27
 		},
-		DEFAULT => -24,
 		GOTOS => {
-			'OPTIONAL-12' => 70,
-			'PAREN-11' => 72
+			'PAREN-13' => 72,
+			'OPTIONAL-14' => 70
 		}
 	},
 	{#State 62
-		ACTIONS => {
-			"and" => 75
-		},
-		DEFAULT => -21,
-		GOTOS => {
-			'OPTIONAL-10' => 73,
-			'PAREN-9' => 74
-		}
+		DEFAULT => -23
 	},
 	{#State 63
-		DEFAULT => -14
-	},
-	{#State 64
-		DEFAULT => -43
-	},
-	{#State 65
 		ACTIONS => {
-			'CODE' => 76
+			'CODE' => 73
 		}
 	},
-	{#State 66
+	{#State 64
+		DEFAULT => -45
+	},
+	{#State 65
 		DEFAULT => -53
 	},
+	{#State 66
+		DEFAULT => -14
+	},
 	{#State 67
-		DEFAULT => -26
+		DEFAULT => -43
 	},
 	{#State 68
-		DEFAULT => -46
+		ACTIONS => {
+			'CODE' => 74
+		}
 	},
 	{#State 69
 		ACTIONS => {
-			'CODE' => 77
+			"," => -21,
+			"=>" => -21,
+			'IDENT' => -21,
+			'CODE' => -21,
+			'REGEXP' => -21,
+			")" => -21,
+			"and" => 77,
+			'' => -21
+		},
+		GOTOS => {
+			'OPTIONAL-10' => 76,
+			'PAREN-9' => 75
 		}
 	},
 	{#State 70
-		DEFAULT => -45
+		DEFAULT => -46
 	},
 	{#State 71
 		ACTIONS => {
@@ -816,27 +918,27 @@ sub new {
 		}
 	},
 	{#State 72
-		DEFAULT => -23
+		DEFAULT => -26
 	},
 	{#State 73
-		DEFAULT => -44
+		DEFAULT => -22
 	},
 	{#State 74
-		DEFAULT => -20
+		DEFAULT => -13
 	},
 	{#State 75
+		DEFAULT => -20
+	},
+	{#State 76
+		DEFAULT => -44
+	},
+	{#State 77
 		ACTIONS => {
 			'CODE' => 79
 		}
 	},
-	{#State 76
-		DEFAULT => -13
-	},
-	{#State 77
-		DEFAULT => -25
-	},
 	{#State 78
-		DEFAULT => -22
+		DEFAULT => -25
 	},
 	{#State 79
 		DEFAULT => -19
@@ -1335,7 +1437,7 @@ sub _Lexer {
 
         return('REGEXP', [$string, $tokenbegin, $options]);
     };
-        $input=~/\G%{/gc
+        $input=~/\G%\{/gc
     and do {
         my($code);
 
@@ -1347,7 +1449,7 @@ sub _Lexer {
         return('Parse::Eyapp::Treeregexp::GLOBALCODE', [$code, $tokenbegin]);
     };
 
-        $input=~/\G{/gc
+        $input=~/\G\{/gc
     and do {
         my($level,$from,$code);
 
@@ -1838,7 +1940,13 @@ package $packagename;
 # This module has been generated using Parse::Eyapp::Treereg
 # from file $filename. Don't modify it.
 # Change $filename instead.
-# Copyright (c) Casiano Rodriguez-Leon 2006. Universidad de La Laguna.
+# Copyright © 2006, 2007, 2008, 2009, 2010, 2011, 2012 Casiano Rodriguez-Leon.
+# Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
+#
+# Parse::Yapp is Copyright © 1998, 1999, 2000, 2001, Francois Desarmenien.
+# Parse::Yapp is Copyright © 2017 William N. Braswell, Jr.
+# All Rights Reserved.
 # You may use it and distribute it under the terms of either
 # the GNU General Public License or the Artistic License,
 # as specified in the Perl README file.
